@@ -86,7 +86,7 @@
 #define PRISON_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PRISON_NO_DEPRECATED
-#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef PRISON_NO_DEPRECATED_WARNINGS
 #  define PRISON_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PRISON_DEPRECATED_WARNINGS_SINCE PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PRISON_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define PRISON_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
@@ -186,7 +186,7 @@
 #define PRISON_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PRISON_NO_DEPRECATED
-#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef PRISON_NO_DEPRECATED_WARNINGS
 #  define PRISON_DEPRECATED_WARNINGS_SINCE 0
@@ -196,7 +196,7 @@
 #  ifdef PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PRISON_DEPRECATED_WARNINGS_SINCE PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PRISON_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define PRISON_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
