@@ -86,7 +86,7 @@
 #define PRISONSCANNER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PRISONSCANNER_NO_DEPRECATED
-#  define PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef PRISONSCANNER_NO_DEPRECATED_WARNINGS
 #  define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
@@ -164,7 +164,7 @@
 #define PRISONSCANNER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PRISONSCANNER_NO_DEPRECATED
-#  define PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef PRISONSCANNER_NO_DEPRECATED_WARNINGS
 #  define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE 0
@@ -174,7 +174,7 @@
 #  ifdef PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
